@@ -1,6 +1,6 @@
 package Hubot;
 {
-  $Hubot::VERSION = '0.2.1';
+  $Hubot::VERSION = '0.2.2';
 }
 
 1;
@@ -30,7 +30,6 @@ example)
 
     [
       "help",
-      "tweet",
       "shorten",
       "ascii"
     ]
@@ -46,7 +45,7 @@ actually, L<Hubot::Message> C<finish> method.
 
 if F<hubot-scripts.json> is not exist, built-in scripts
 
-"help", "tweet", "ascii", "roles"
+"help", "ascii", "roles"
 
 are loaded automatically.
 
